#*******************************************************************************
#                  INITIAL OPERATIONS
more off; clc;  rand('state',0);  randn('state',0);
#*******************************************************************************
#                  PATHS (global variables):
global ver csdir resdir nof nloops nips ni nsc ev ev0 ph ph0 en ...
       dtctr src smpl simtime sp err;
ver='2.0';                                                      # MUSCAT version
if ispc
    muscatdir='D:/Dropbox/MUSCAT/OCTAVE/';                       # MUSCAT folder
elseif isunix
    muscatdir='/home/brancew/Dropbox/MUSCAT/OCTAVE/';            # MUSCAT folder
endif
fundir=[muscatdir 'functions/'];                              # functions folder
geodir=[muscatdir 'geometries/'];                            # geometries folder
samdir=[muscatdir 'samples/'];                                  # samples folder
csdir=[muscatdir 'crossections/'];                       # cross sections folder
resdir=[muscatdir 'results/v' ver '/'];                         # results folder
#*******************************************************************************
#                  LOADING FUNCTIONS & PARAMETERS
source([fundir 'funload.txt']);
source([geodir 'test_geometry.m']);
source([samdir 'test_sample.m']);
showgeometry(0.1,'n');                                # for visual geometry test
#*******************************************************************************
#                  INITIAL PARAMETERS
nsc=3;                                                   # number of scatterings
nof=100000;                                                  # number of photons
nloops=1;                                                      # number of loops
nips=0;                                                 # inc. photons at sample
ev0=0;  ev=zeros(nsc,1);  ph0=0;  ph=zeros(nsc,1);    # detected events, photons
#*******************************************************************************
#                  MCA PARAMETERS
#                   energy scale: min. & max. energy [keV], number of intervals:
[emin,emax,ni]=scale4mca();                                # automatic MCA scale
#emin=60;    emax=120;    ni=(emax-emin)*10;                  # manual MCA scale
en=linspace(emin,emax,ni+1)';                        # energy scale for s pectra
sp=zeros(ni+1,nsc);                                              # empty spectra
err=zeros(ni+1,nsc);                                              # empty errors
#*******************************************************************************
#                  MAIN PROGRAM
tic();                                                             # start timer
for i=1:nloops
    disp(['******* MUSCAT ' ver ' LOOP no. ' num2str(i)]);
    B=beamsim(nof,nsc);
    [B,B_det,op]=beam2sample(B,'n');
    ev0=ev0+size(B_det.r,1);  ph0=ph0+sum(B_det.wgt);
    nips=nips+size(B.r,1);
    B=prop0(B,op,'n');                        # propagate to 1st interaction point
    for j=1:nsc
        Bd=prop2det(j,B,'n');                        # j-th scattering to detector
        B_det=detect(Bd);
        ev(j)=ev(j)+size(B_det.r,1);
        ph(j)=ph(j)+sum(B_det.wgt);
        [sm,em]=mca(B_det,emin,emax,ni);
        sp(:,j)=sp(:,j)+sm;
        err(:,j)=sqrt(err(:,j).^2+em.^2);
        B=prop2sam(j,B,'n');                    # j-th scattering to sample volume
    endfor
endfor
[en,sp]=detres(en,sp,dtctr.res);    # applying detector resolution (convolution)
simtime=datestr(toc()/86400,13);                                    # stop timer
#*******************************************************************************
#                         RESULTS: DISPLAY, SAVE & PLOT
showresults();
saveresults();
plotresults('lin');
chdir(muscatdir);
clear;
#*******************************************************************************