1;	#for octave to recognize this as script file and load all functions
#*******************************************************************************
# 1) AFFLOAD - loading atomic form factor for elastic scattering table from
#              /crossections/Xx.aff file (Xx - element)
# 2) AFFCALC - calculation of elastic atomic form factor values for every
#              photon from the beam based on their energy, scattering angle
#              and material type
#*******************************************************************************
function [aff]=affload(matname)
global csdir
    filename=[csdir '/' matname '.aff'];
    fid=fopen(filename,'rt');
    if fid==-1
        disp(['Error while opening crossection file: ' filename]);  return;
    endif
    aff=reshape(fscanf(fid,'%e %e'),2,[])';      # read atomic form factor table   
    fclose(fid);
endfunction
#*******************************************************************************
function [aff]=affcalc(B,matname,scang)
    h=4.135667516e-18;                                 # Planck constant [keV*s]
    c=299792458;                                          # speed of light [m/s]
    dat=affload(matname);                               # read form factor table
    x=dat(:,1);    y=dat(:,2);
    lambda=1e10*h*c./B.ene;                                     # wavelength [A]
    xff=sin(scang/2)./lambda;                                            # [1/A]
    aff=interp1(x,y,xff,'spline');
endfunction
#*******************************************************************************
