1;	#for octave to recognize this as script file and load all functions
#*******************************************************************************
# BEAM2SAMPLE - beam propagation to the sample surface.
# Columns 13,14,15 are temporarily used as a place for saving the
# coordinates of the exit points.
#    B     - matrix of any photons beam
#    B_out - detected photons that won't hit the sample
#    B_in  - photons at input point (at sample surface)
#    outp  - output points
#*******************************************************************************
function [B_in,B_out,outp]=beam2sample(B,fig)
    global smpl nof;
    disp('_______ BEAM2SAMPLE');
    sh=smpl.shape;
    wm=smpl.width;  lm=smpl.length;  hm=smpl.height;
    tx=smpl.trx;    ty=smpl.try;     tz=smpl.trz;
    x0=B.r(:,1);  y0=B.r(:,2);  z0=B.r(:,3);               # photons coordinates
    kx=B.k(:,1);  ky=B.k(:,2);  kz=B.k(:,3);            # propagation directions

    switch smpl.shape                     # test for photons that hit the sample
    case 'cuboid'
        B.k(B.k==0)=1e-12;             # if there is k component = 0 (very rare)
        # photons coordinates & directions:
        nos=size(B.r,1);                       # number of photons in the sample
        # 6 sample surfaces:
        xmin=(-smpl.width/2)+smpl.trx;    xmax=xmin+smpl.width;
        ymin=(-smpl.length/2)+smpl.try;   ymax=ymin+smpl.length;
        zmin=(-smpl.height/2)+smpl.trz;   zmax=zmin+smpl.height;
        # crossing points with all 6 surfaces:
        x1=ones(nos,1)*xmin;  d1=(x1-x0)./kx;  y1=(d1.*ky)+y0;  z1=(d1.*kz)+z0;
        x2=ones(nos,1)*xmax;  d2=(x2-x0)./kx;  y2=(d2.*ky)+y0;  z2=(d2.*kz)+z0;
        y3=ones(nos,1)*ymin;  d3=(y3-y0)./ky;  x3=(d3.*kx)+x0;  z3=(d3.*kz)+z0;
        y4=ones(nos,1)*ymax;  d4=(y4-y0)./ky;  x4=(d4.*kx)+x0;  z4=(d4.*kz)+z0;
        z5=ones(nos,1)*zmin;  d5=(z5-z0)./kz;  x5=(d5.*kx)+x0;  y5=(d5.*ky)+y0;
        z6=ones(nos,1)*zmax;  d6=(z6-z0)./kz;  x6=(d6.*kx)+x0;  y6=(d6.*ky)+y0;
        tst1=and(x1>=xmin,y1>=ymin,z1>=zmin,x1<=xmax,y1<=ymax,z1<=zmax);
        tst2=and(x2>=xmin,y2>=ymin,z2>=zmin,x2<=xmax,y2<=ymax,z2<=zmax);
        tst3=and(x3>=xmin,y3>=ymin,z3>=zmin,x3<=xmax,y3<=ymax,z3<=zmax);
        tst4=and(x4>=xmin,y4>=ymin,z4>=zmin,x4<=xmax,y4<=ymax,z4<=zmax);
        tst5=and(x5>=xmin,y5>=ymin,z5>=zmin,x5<=xmax,y5<=ymax,z5<=zmax);
        tst6=and(x6>=xmin,y6>=ymin,z6>=zmin,x6<=xmax,y6<=ymax,z1<=zmax);
        tst=or(tst1,tst2,tst3,tst4,tst5,tst6);
        B_in=beamextract(B,tst);                   # photons that hit the sample
        B_out=beamextract(B,~tst);           # photons that won't hit the sample
        d=dist2entrance(B_in);
        B_in.r+=B_in.k.*d;                       # propagation to sample surface
        
    case 'roller'
        # tx,ty - roller central axis
        # photon path square distance from the middle of the roller
        d2=(((tx-x0).*ky-(ty-y0).*kx).^2)./(kx.^2+ky.^2);
        tst=d2<=(wm/2)^2;                  # must be less or equal square radius
        B_in=beamextract(B,tst);          # photons that hit the infinite roller       
        B_out1=beamextract(B,~tst);   # photons that won't hit the sample part 1
        [d1,d2]=dist_infroller(B_in);              # distance to infinite roller       
        r1=B_in.r+B_in.k.*d1;          # entrance coordinates at infinite roller
        r2=B_in.r+B_in.k.*d2;              # exit coordinates at infinite roller
                           # test for outside the roller (check by z coordinate)
        tst1=and(r1(:,3)>(hm/2+tz),r2(:,3)>(hm/2+tz));
        tst2=and(r1(:,3)<(-hm/2+tz),r2(:,3)<(-hm/2+tz));
        tst=or(tst1,tst2);
        B_in2=beamextract(B_in,~tst);
        B_out2=beamextract(B_in,tst);        
        B_out=beammerge(B_out1,B_out2);
        B_in=B_in2;
        d=dist2entrance(B_in);
        B_in.r+=B_in.k.*d;                           # propagation to the roller
        
    case 'ball'
        # tx,ty,tz - middle of the ball
        # photon path square distance from the middle of the ball
        d2=(((tx-x0).*ky-(ty-y0).*kx).^2+((ty-y0).*kz-(tz-z0).*ky).^2+ ...
            ((tz-z0).*kx-(tx-x0).*kz).^2)./(kx.^2+ky.^2+kz.^2);
        tst=d2<=(wm/2)^2;                  # must be less or equal square radius
        B_in=beamextract(B,tst);                   # photons that hit the sample
        B_out=beamextract(B,~tst);           # photons that won't hit the sample
        d=dist2entrance(B_in);                    # distance to the ball surface
        B_in.r+=B_in.k.*d;                       # propagation to sample surface

    otherwise
        disp('Unsupported sample shape !');  return;
    endswitch
    
    if size(B_out.r,1)>0                             # check B_out for detection
        B_out=detect(B_out);
    endif
    if size(B_out.r,1)>0                          # if incident photons detected
        disp('WARNING! - incident photons detected');
    endif
    
    B_in.loc(:,:)=0.5;                    # set location to sample surface (0.5)
    d=dist2exit(B_in);
    B_in2=B_in;       # temporary beam structure matrix B_in2 with output points
    B_in2.r+=B_in2.k.*d;                            # propagation to sample exit
    outp=B_in2.r;                                          # need this for prop0
    
    if fig=='f'                             # test figure; entry and exit points
        figure;
        hold on;
        title('Entry & exit points','color','blue','fontsize',16);
        plot_sample('e');
        plot_photons(B_in,'r');                                   # entry points
        plot_photons(B_in2,'g');                                   # exit points
        axis("equal");
        view(70,20);
    endif
endfunction
#*******************************************************************************
