1;	#for octave to recognize this as script file and load all functions
#*******************************************************************************
# 1) BEAMEXTRACT - function that extracts a part of a beam structure matrix
#                  B - structure matrix of any photons
#                  B_t - part of structure matrix for cond=True
# 2)   BEAMMERGE - function that mergess two beam structure matrices into one
#                  B - merged beam structure matrix
#                  B1,B2 - beam structure matrices to be merged
# 3)      ROTDET - Beam rotation to detection direction (Z)
# 2)     ROTBACK - Beam back rotation from detection direction
#*******************************************************************************
function [B_t]=beamextract(B,cond)
    global ver;
    switch ver
    case '1.0'
        B_t=struct('r',B.r(cond,:),'k',B.k(cond,:),...
                   'ene',B.ene(cond,:),'wgt',B.wgt(cond,:),...
                   'loc',B.loc(cond,:),'pr',B.pr(cond,:));
    case '2.0'
        B_t=struct('r',B.r(cond,:),'k',B.k(cond,:),...
                   'ene',B.ene(cond,:),'wgt',B.wgt(cond,:),...
                   'loc',B.loc(cond,:),'pr',B.pr(cond,:),...
                   'e',B.e(cond,:));
    case '3.0'
        B_t=struct('r',B.r(cond,:),'k',B.k(cond,:),...
                   'ene',B.ene(cond,:),'wgt',B.wgt(cond,:),...
                   'loc',B.loc(cond,:),'pr',B.pr(cond,:),...
                   'n',B.n(cond,:),'s',B.s(cond,:));
    otherwise
        disp('BEAMEXTRACT: Wrong MUSCAT version!');  return;
    endswitch
endfunction
#*******************************************************************************
function [B]=beammerge(B1,B2)
    global ver;
    switch ver
    case '1.0'
        B=struct('r',[B1.r;B2.r],'k',[B1.k;B2.k],...
                 'ene',[B1.ene;B2.ene],'wgt',[B1.wgt;B2.wgt],...
                 'loc',[B1.loc;B2.loc],'pr',[B1.pr;B2.pr]);
    case '2.0'
        B=struct('r',[B1.r;B2.r],'k',[B1.k;B2.k],...
                 'ene',[B1.ene;B2.ene],'wgt',[B1.wgt;B2.wgt],...
                 'loc',[B1.loc;B2.loc],'pr',[B1.pr;B2.pr],...
                 'e',[B1.e;B2.e]);
    case '3.0'
        B=struct('r',[B1.r;B2.r],'k',[B1.k;B2.k],...
                 'ene',[B1.ene;B2.ene],'wgt',[B1.wgt;B2.wgt],...
                 'loc',[B1.loc;B2.loc],'pr',[B1.pr;B2.pr],...
                 'n',[B1.n;B2.n],'s',[B1.s;B2.s]);
    otherwise
        disp('BEAMMERGE: Wrong MUSCAT version!');  return;
    endswitch
endfunction
#*******************************************************************************
function [Bo]=rotdet(Bi)
    global dtctr;
    Bo=Bi;
    xyz0=Bi.r;
    xyz1=Bi.r+Bi.k;
    xyz0=rotzyx(xyz0,-dtctr.rotx,-dtctr.roty,-dtctr.rotz);
    xyz1=rotzyx(xyz1,-dtctr.rotx,-dtctr.roty,-dtctr.rotz);
    Bo.r=xyz0;
    Bo.k=xyz1-xyz0;
endfunction
#*******************************************************************************
function [Bo]=rotback(Bi)
  global dtctr;
    Bo=Bi;
    xyz0=Bi.r;
    xyz1=Bi.r+Bi.k;
    xyz0=rotxyz(xyz0,dtctr.rotx,dtctr.roty,dtctr.rotz);
    xyz1=rotxyz(xyz1,dtctr.rotx,dtctr.roty,dtctr.rotz);
    Bo.r=xyz0;
    Bo.k=xyz1-xyz0;
endfunction
#*******************************************************************************