1;	#for octave to recognize this as script file and load all functions
#*******************************************************************************
# DETECT - detection function
#    B     - matrix of any photons
#    B_det - matrix of photons that can be detected and finally detected
#*******************************************************************************
function [B_det]=detect(B)
    global dtctr smpl;
    disp('_______ DETECT');
    if any(B.loc==1)                          # if there is photon inside sample
        disp('DETECT: Possible detection of photon from the sample !')
    endif
    B_det=rotdet(B);                           # rotation to detection direction
    tst=B_det.k(:,3)>0;
    B_det=beamextract(B_det,tst);                     # select only kz>0 photons
    zd=dtctr.inpos;                                          # detector position
    zc=dtctr.inpos-dtctr.colength;                # collimator entrance position
    dc=(zc-B_det.r(:,3))./B_det.k(:,3);     # dist. to collimator entrance surf.
    B_det.r+=B_det.k.*dc;                            # prop. to collimator surf.
    switch dtctr.type                # select collimator type ('circ' or 'rect')
    case 'circ'
        r=dtctr.colx/2;                           # collimator & detector radius
        col=(B_det.r(:,1).^2+B_det.r(:,2).^2)<=r^2;    # check collimation cond.
        B_det=beamextract(B_det,col);
        dd=(zd-B_det.r(:,3))./B_det.k(:,3);               # distance to detector
        B_det.r+=B_det.k.*dd;                          # propagation to detector
        dtc=(B_det.r(:,1).^2+B_det.r(:,2).^2)<=r^2;  # check detection condition
        B_det=beamextract(B_det,dtc);                         # photons detected
    case 'rect'
        dx=dtctr.colx;  dy=dtctr.coly;        # collimator & detector dimensions
        col=all([abs(B_det.r(:,1))<=dx/2,abs(B_det.r(:,2))<=dy/2],2);
        B_det=beamextract(B_det,col);
        dd=(zd-B_det.r(:,3))./B_det.k(:,3);               # distance to detector
        B_det.r+=B_det.k.*dd;                          # propagation to detector
        dtc=all([abs(B_det.r(:,1))<=dx/2,abs(B_det.r(:,2))<=dy/2],2);
        B_det=beamextract(B_det,dtc);                         # photons detected
    otherwise
        disp('DETECT: Inproper collimator type!');  return;
    endswitch
    B_det=rotback(B_det);                                        # back rotation
endfunction
#*******************************************************************************