1;	#for octave to recognize this as script file and load all functions
#*******************************************************************************
# DIST2EXIT - calculates the photon distances (in [m]) to the exit points
#    from the sample
#*******************************************************************************
function [dist]=dist2exit(B)
    global smpl;
    switch smpl.shape
    case 'cuboid'
        [den,dist]=dist_cuboid(B);
    case 'roller'
        [den,dist]=dist_roller(B);
    case 'ball'
        [den,dist]=dist_ball(B);
    endswitch
endfunction
#*******************************************************************************
function [dist]=dist2entrance(B)
    global smpl;
    switch smpl.shape
    case 'cuboid'
        [dist,dex]=dist_cuboid(B);
    case 'roller'
        [dist,dex]=dist_roller(B);
    case 'ball'
        [dist,dex]=dist_ball(B);
    endswitch
endfunction
#*******************************************************************************
function [dentr,dexit]=dist_cuboid(B)
    global smpl;
    B.k(B.k==0)=1e-12;                 # if there is k component = 0 (very rare)
    # photons coordinates & directions:
    x0=B.r(:,1);    y0=B.r(:,2);    z0=B.r(:,3);
    kx=B.k(:,1);    ky=B.k(:,2);    kz=B.k(:,3);
    nos=size(B.r,1);                           # number of photons in the sample
    # 6 sample surfaces:
    xmin=(-smpl.width/2)+smpl.trx;    xmax=xmin+smpl.width;
    ymin=(-smpl.length/2)+smpl.try;   ymax=ymin+smpl.length;
    zmin=(-smpl.height/2)+smpl.trz;   zmax=zmin+smpl.height;
    # crossing points with all 6 surfaces:
    x1=ones(nos,1)*xmin;  h1=(x1-x0)./kx;  y1=(h1.*ky)+y0;  z1=(h1.*kz)+z0;
    x2=ones(nos,1)*xmax;  h2=(x2-x0)./kx;  y2=(h2.*ky)+y0;  z2=(h2.*kz)+z0;
    y3=ones(nos,1)*ymin;  h3=(y3-y0)./ky;  x3=(h3.*kx)+x0;  z3=(h3.*kz)+z0;
    y4=ones(nos,1)*ymax;  h4=(y4-y0)./ky;  x4=(h4.*kx)+x0;  z4=(h4.*kz)+z0;
    z5=ones(nos,1)*zmin;  h5=(z5-z0)./kz;  x5=(h5.*kx)+x0;  y5=(h5.*ky)+y0;
    z6=ones(nos,1)*zmax;  h6=(z6-z0)./kz;  x6=(h6.*kx)+x0;  y6=(h6.*ky)+y0;
    cmp=[x1,y1,z1,x2,y2,z2,x3,y3,z3,x4,y4,z4,x5,y5,z5,x6,y6,z6];
    cmp=reshape(cmp',3,6*nos)';                                 # rebuild matrix
    # next test for crossing points at the sample surfaces:
    tst=all([cmp(:,1)>=xmin,cmp(:,2)>=ymin,cmp(:,3)>=zmin,...
             cmp(:,1)<=xmax,cmp(:,2)<=ymax,cmp(:,3)<=zmax],2);    
    cmp=cmp(tst,:);                         # reduce cmp to only crossing points
    cmp=reshape(cmp',6,nos)';                                   # rebuild matrix
    v1=cmp(:,1:3)-B.r;
    v2=cmp(:,4:6)-B.r;
    d1=sqrt(sum(v1.^2,2));    dentr=d1;
    d2=sqrt(sum(v2.^2,2));    dexit=d2;
    if or(all(B.loc==0),all(B.loc==0.5))
        tst=d1<d2;
        dentr(~tst)=d2(~tst);
        dexit(~tst)=d1(~tst);
    elseif all(B.loc==1)
        tst=dot(B.k',v1')'>0;
        dentr(tst)=d2(tst);
        dexit(tst)=d1(tst);
        dentr*=-1;                      # because entry was in oposite direction
    endif
    
    #r1=B.r+B.k.*dentr;  r2=B.r+B.k.*dexit;                        # visual test
    #figure;  hold on;
    #scatter3(r1(:,1),r1(:,2),r1(:,3),'r','.');
    #scatter3(r2(:,1),r2(:,2),r2(:,3),'g','.');
    #axis('equal');  view(70,20);
endfunction
#*******************************************************************************
function [dentr,dexit]=dist_roller(B)
    global smpl;
    r=smpl.width/2;  hm=smpl.height;
    tx=smpl.trx;     ty=smpl.try;     tz=smpl.trz;
    x1=B.r(:,1);     y1=B.r(:,2);     z1=B.r(:,3);
    x2=x1+B.k(:,1);  y2=y1+B.k(:,2);  z2=z1+B.k(:,3);
    [d1,d2]=dist_infroller(B);
    r1=B.r+B.k.*d1;                    # entrance coordinates at infinite roller
    r2=B.r+B.k.*d2;                        # exit coordinates at infinite roller 
    # correcting entry points
    t=r1(:,3)>hm/2+tz;                                  # hit the top first test
    z=hm/2+tz;
    r1(t,1)=((z-r1(t,3)).*(r2(t,1)-r1(t,1)))./(r2(t,3)-r1(t,3))+r1(t,1);
    r1(t,2)=((z-r1(t,3)).*(r2(t,2)-r1(t,2)))./(r2(t,3)-r1(t,3))+r1(t,2);
    r1(t,3)=z;
    t=r1(:,3)<-hm/2+tz;                              # hit the bottom first test
    z=-hm/2+tz;
    r1(t,1)=((z-r1(t,3)).*(r2(t,1)-r1(t,1)))./(r2(t,3)-r1(t,3))+r1(t,1);
    r1(t,2)=((z-r1(t,3)).*(r2(t,2)-r1(t,2)))./(r2(t,3)-r1(t,3))+r1(t,2);
    r1(t,3)=z;
    # correcting exit points
    t=r2(:,3)>hm/2+tz;                                           # top exit test
    z=hm/2+tz;
    r2(t,1)=((z-r1(t,3)).*(r2(t,1)-r1(t,1)))./(r2(t,3)-r1(t,3))+r1(t,1);
    r2(t,2)=((z-r1(t,3)).*(r2(t,2)-r1(t,2)))./(r2(t,3)-r1(t,3))+r1(t,2);
    r2(t,3)=z;
    t=r2(:,3)<-hm/2+tz;                                       # bottom exit test
    z=-hm/2+tz;
    r2(t,1)=((z-r1(t,3)).*(r2(t,1)-r1(t,1)))./(r2(t,3)-r1(t,3))+r1(t,1);
    r2(t,2)=((z-r1(t,3)).*(r2(t,2)-r1(t,2)))./(r2(t,3)-r1(t,3))+r1(t,2);
    r2(t,3)=z;
    dentr=sqrt(sum((r1-B.r).^2,2));
    dexit=sqrt(sum((r2-B.r).^2,2));

    #figure;  hold on;                                             # visual test
    #scatter3(r1(:,1),r1(:,2),r1(:,3),'r','.');
    #scatter3(r2(:,1),r2(:,2),r2(:,3),'g','.');
    #axis('equal');  view(70,20);    
endfunction
#*******************************************************************************
function [dentr,dexit]=dist_infroller(B)
    global smpl;
    r=smpl.width/2;    tx=smpl.trx;    ty=smpl.try;     tz=smpl.trz;
    x1=B.r(:,1);     y1=B.r(:,2);     z1=B.r(:,3);
    x2=x1+B.k(:,1);  y2=y1+B.k(:,2);  z2=z1+B.k(:,3);
    a=(y1-y2)./(x1-x2);
    b=y1-a.*x1;
    c=(z1-z2)./(y1-y2);
    d=z1-c.*y1;
    AA=1+a.^2;
    BB=-2*(tx-a.*(b-ty));
    CC=tx^2+(b-ty).^2-r^2;
    DD=BB.^2-4*AA.*CC;
    SD=sqrt(DD);
    X1=(-BB-SD)./(2*AA);  Y1=a.*X1+b;  Z1=c.*Y1+d;
    X2=(-BB+SD)./(2*AA);  Y2=a.*X2+b;  Z2=c.*Y2+d;
    v1=[X1,Y1,Z1]-B.r;
    v2=[X2,Y2,Z2]-B.r;
    d1=sqrt(sum(v1.^2,2));    dentr=d1;
    d2=sqrt(sum(v2.^2,2));    dexit=d2;
    if or(all(B.loc==0),all(B.loc==0.5))   # for photons outside and on the surf
        tst=d1<d2;
        dentr(~tst)=d2(~tst);
        dexit(~tst)=d1(~tst);
    elseif all(B.loc==1);                        # for photons inside the sample
        tst=dot(B.k',v1')'>0;
        dentr(tst)=d2(tst);
        dexit(tst)=d1(tst);
        dentr*=-1;                      # because entry was in oposite direction
    endif
    
    #r1=B.r+B.k.*dentr;  r2=B.r+B.k.*dexit;                        # visual test
    #figure;  hold on;                    
    #scatter3(r1(:,1),r1(:,2),r1(:,3),'r','.');
    #scatter3(r2(:,1),r2(:,2),r2(:,3),'g','.');
    #axis('equal');  view(70,20);
endfunction
#*******************************************************************************
function [dentr,dexit]=dist_ball(B)
    global smpl;
    r=smpl.width/2;    tx=smpl.trx;    ty=smpl.try;     tz=smpl.trz;
    x1=B.r(:,1);     y1=B.r(:,2);     z1=B.r(:,3);
    x2=x1+B.k(:,1);  y2=y1+B.k(:,2);  z2=z1+B.k(:,3);
    a=(y1-y2)./(x1-x2);
    b=y1-a.*x1;
    c=(z1-z2)./(y1-y2);
    d=z1-c.*y1;
    AA=1+a.^2.*(1+c.^2);
    BB=-2*(tx-a.*(b-ty)-a.*c.*(b.*c+d-tz));
    CC=tx^2+(b-ty).^2+(b.*c+d-tz).^2-r^2;
    DD=BB.^2-4*AA.*CC;
    SD=sqrt(DD);
    X1=(-BB-SD)./(2*AA);  Y1=a.*X1+b;  Z1=c.*Y1+d;
    X2=(-BB+SD)./(2*AA);  Y2=a.*X2+b;  Z2=c.*Y2+d;
    v1=[X1,Y1,Z1]-B.r;
    v2=[X2,Y2,Z2]-B.r;
    d1=sqrt(sum(v1.^2,2));    dentr=d1;
    d2=sqrt(sum(v2.^2,2));    dexit=d2;
    if or(all(B.loc==0),all(B.loc==0.5))   # for photons outside and on the surf
        tst=d1<d2;
        dentr(~tst)=d2(~tst);
        dexit(~tst)=d1(~tst);
    elseif all(B.loc==1);                        # for photons inside the sample
        tst=dot(B.k',v1')'>0;
        dentr(tst)=d2(tst);
        dexit(tst)=d1(tst);
        dentr*=-1;                      # because entry was in oposite direction
    endif
    
    #r1=B.r+B.k.*dentr;  r2=B.r+B.k.*dexit;                        # visual test
    #figure;  hold on;
    #scatter3(r1(:,1),r1(:,2),r1(:,3),'r','.');
    #scatter3(r2(:,1),r2(:,2),r2(:,3),'g','.');
    #axis('equal');  view(70,20);
endfunction
#*******************************************************************************