1;	#for octave to recognize this as script file and load all functions
#*******************************************************************************
# Calculates momentum scale.
# e0 = incident energies [keV] (table)
# e1 = scattered energies [keV] (table)
# th = scattering angles [rad] (table)
# pz = momentum scale [a.u.] (table)
#*******************************************************************************
# Holm, PRA 37, 3706 (1988):
function [pz]=ec2pz(e0,th,e1)
    m=510.99891;                                   # electron rest mass in [keV]
    alp=1/137.036;                                     # fine structure constant
    q=sqrt(e0.^2+e1.^2-2*e0.*e1.*cos(th));                   # momentum transfer
    pz=(q/2)-(e0-e1).*sqrt(1/4+m^2 ./(2*e0.*e1.*(1-cos(th))));
    pz=pz/(m*alp);                                              # momentum scale
endfunction
#*******************************************************************************
# A.Andrejczuk (phd thesis), N.Sakai, J.Phys.Soc.Jpn. 56, 7, 2477-2485 (1987)
function [pz]=ec2pz1(e0,th,e1)
    m=510.99891;                                   # electron rest mass in [keV]
    alp=1/137.036;                                     # fine structure constant
    A=1 ./(1+(e0/m).*(1-cos(th)));
    pz=(e1-A.*e0)./(alp*A.*e0.*sqrt(1+A.^2-2*A.*cos(th)));
endfunction
#*******************************************************************************
