1;	#for octave to recognize this as script file and load all functions
#*******************************************************************************
# 1) ISFLOAD - loading incoherent scattering function table from
#              /crossections/Xx.isf file (Xx - element)
# 2) ISFCALC - calculation of incoherent scattering function values for
#              every photon from the beam based on their energy,
#              scattering angle and material type.
#*******************************************************************************
function [isf]=isfload(matname)
    global csdir;
    filename=[csdir '/' matname '.isf'];
    [fid,err]=fopen(filename,'rt');
    if err!=0
        disp(['Error while opening crossection file: ' filename]);  return;
    endif
    isf=reshape(fscanf(fid,'%e %e'),2,[])';      # read atomic form factors data
    fclose(fid);
endfunction
#*******************************************************************************
function [isf]=isfcalc(B0,matname,scang)
    h=4.135667516e-18;                                 # Planck constant [keV*s]
    c=299792458;                                          # speed of light [m/s]
    m=510.99891;                                   # electron rest mass in [keV]
    dat=isfload(matname);                               # read form factor table
    x=dat(:,1);    y=dat(:,2);
    lambda=1e10*h*c./B0.ene;                                    # wavelength [A]
    xsf=sin(scang/2)./lambda;           # elastic momentum transfer param. [1/A]
    isf=interp1(x,y,xsf,'spline');
endfunction
#*******************************************************************************
