1;	#for octave to recognize this as script file and load all functions
#*******************************************************************************
# 1) MACLOAD - read mass attenuation coefficients (MAC) [cm2/g]
# 2) MACVIEW - plots MAC data
# 3) MACCALC - MAC calculations for the beam matrix
#*******************************************************************************
function [mac]=macload(matname);
    global csdir;
    chdir(csdir);                      # change path to cross sections directory
    filename=[csdir '/' matname '.mac'];
    fid=fopen(filename,'rt');                 # open file with crossections data
    if fid==-1
        disp(['Error while opening crossection file: ' filename]);  return;
    endif
    for i=1:13
    	fgetl(fid);                                        # read 13 comment lines
    endfor
    #dat=reshape(fscanf(fid,'%e %e %e %e %e %e %e %e'),8,[])';
    dat=fscanf(fid,'%e %e %e %e %e %e %e %e');           # read crossection data
    dat=reshape(dat,8,[])';
    en=dat(:,1)*1000;                                           # energies [keV]
    cs=dat(:,2);                           # MAC for coherent scattering [cm2/g]
    is=dat(:,3);                         # MAC for incoherent scattering [cm2/g]
    pa=dat(:,4);                      # MAC for photoelectric absorption [cm2/g]
    ta=dat(:,7);                                             # MAC total [cm2/g]
    fclose(fid);
    mac=[en,cs,is,pa];                                # creating MAC data matrix
endfunction
#*******************************************************************************
function []=macview(matname)
    dat=macload(matname);                                       # read MAC table
    en=dat(:,1);   cs=dat(:,2);   is=dat(:,3);   pa=dat(:,4);   ta=cs+is+pa;
    figure; hold on;
    title(['NIST mass att. coeff. for ' matname],'color','blue','fontsize',16);
    semilogy(en,cs,'r');
    semilogy(en,is,'g');
    semilogy(en,pa,'b');
    semilogy(en,ta,'k');
    xlabel('E [keV]','fontsize',16);
    ylabel('\sigma [cm^2/g]','fontsize',16);
endfunction
#*******************************************************************************
function [mac]=maccalc(B0,matname)
    dat=macload(matname);                                       # read MAC table
    en=dat(:,1);   cs=dat(:,2);   is=dat(:,3);   pa=dat(:,4);
    b0_en=B0.ene;                                          # photon energy [keV]  
    b0_cs=interp1(en,cs,b0_en,'spline');                    # MAC for coh. scat.
    b0_is=interp1(en,is,b0_en,'spline');                  # MAC for incoh. scat.
    b0_pa=interp1(en,pa,b0_en,'spline');                 # MAC for photoel. abs.
    mac=[b0_en,b0_cs,b0_is,b0_pa];
endfunction
#*******************************************************************************
