1;	#for octave to recognize this as script file and load all functions
#*******************************************************************************
# 2) SCALE4MCA - Calculation of energy scale: min, max, number of intervals
#                for multichannel analyzer (MCA)
#         emin - min. value of energy [keV]
#         emax - max. value of energy [keV]
#         ni   - number of intervals between emin and emax
# 2) MCA  - extracting energy spectrum (intens) from the beam matrix
# 3) MCA2 - extracting partial energy spectra (intens) from the beam matrix
#*******************************************************************************
function [emin,emax,ni]=scale4mca()
    global src;
    theta=scancal();
    hw=src.energy;
    minpz=-11;
    hw1=pz2ec(hw,theta,minpz);
    emin=floor(hw1);
    emax=round(hw+1);
    ni=(emax-emin)*10;                   # number of intervals (width = 0.1 keV)
#   disp(['MCA range: E_min=' num2str(emin) ', E_max=' num2str(emax) ' [keV]']);
endfunction
#*******************************************************************************
function [intens,err]=mca(B,emin,emax,ni)
    disp('_______ MCA');
    de=(emax-emin)/ni;                                     # channel width [keV]
    en=linspace(emin-(de/2),emax+(de/2),ni+2)';               # energy intervals    
    ind=length(en)-lookup(en(end:-1:1),B.ene);
    ind(ind==length(en))=0;
    ind(B.ene==en(1))+=1;
    
# by Michael Leitner:            (MB: seems not working with all energy scales)
#    intens=full(sparse(1+ind,1,B.wgt,ni+2,1))(2:end)/de;
#    err=intens./sqrt(full(sparse(1+ind,1,1,ni+2,1))(2:end));
#    err(isnan(err))=0;

# by MB:
    for i=1:ni+1
        intens(i,:)=sum(B.wgt(ind==i,:))/de; # intensity in interval phot./keV]
        nev=size(B.r(ind==i,:),1);                # number of events in channel
        if nev==0
            err(i,:)=0;
        else
            err(i,:)=intens(i)./sqrt(nev);
        endif
    endfor
endfunction
#*******************************************************************************
function [intens,err]=mca2(B,emin,emax,ni)
    tee=and(B.pr(:,1)==1,B.pr(:,2)==1);                      # elastic - elastic
    Bee=beamextract(B,tee);
    [intens(:,1),err(:,1)]=mca(Bee,emin,emax,ni);

    tei=and(B.pr(:,1)==1,B.pr(:,2)==2);                    # elastic - inelastic
    Bei=beamextract(B,tei);
    [intens(:,2),err(:,2)]=mca(Bei,emin,emax,ni);
    
    tie=and(B.pr(:,1)==2,B.pr(:,2)==1);                    # inelastic - elastic
    Bie=beamextract(B,tie);
    [intens(:,3),err(:,3)]=mca(Bie,emin,emax,ni);

    tii=and(B.pr(:,1)==2,B.pr(:,2)==2);                  # inelastic - inelastic
    Bii=beamextract(B,tii);
    [intens(:,4),err(:,4)]=mca(Bii,emin,emax,ni);
endfunction
#*******************************************************************************

