1;	#for octave to recognize this as script file and load all functions
#*******************************************************************************
# 1) PLOT_SAMPLE  -  ploting sample (typ = 's' - surfaces, 'e' - edges)
# 2) PLOT_BEAM    -  ploting incident beam
# 3) PLOT_DETCONE -  ploting detection cone
# 4) PLOT_PHOTONS -  ploting photons positions
#*******************************************************************************
function plot_sample(typ)
    global smpl;
    sh=smpl.shape;
    wm=smpl.width;  lm=smpl.length;  hm=smpl.height;
    tx=smpl.trx;    ty=smpl.try;     tz=smpl.trz;
    
    ecol=[0.0;0.2;0.4];                     # color for sample edges (dark blue)
    switch typ
    case 's'                           # face color for plotting sample surfaces
        fcol=[0.6;0.8;1.0];
    case 'e'                           # no face color for plotting sample edges
        fcol='none';
    otherwise
        disp('Incorrect PLOT_SAMPLE input parameter !');  return;
    endswitch
    
    switch smpl.shape
    case 'cuboid'                                        # ploting cuboid sample
        w=wm/2;  l=lm/2;  h=hm/2;
        x1=[-w,w;-w,w];    y1=[-l,-l;-l,-l];  z1=[-h,-h;h,h];
        x2=x1;             y2=[l,l;l,l];      z2=z1;
        x3=[-w,w;-w,w];    y3=[-l,-l;l,l];    z3=[-h,-h;-h,-h];
        x4=x3;             y4=y3;             z4=[h,h;h,h];
        x5=[-w,-w;-w,-w];  y5=[-l,l;-l,l];    z5=[-h,-h;h,h];
        x6=[w,w;w,w];      y6=y5;             z6=z5;
        surf(x1+tx,y1+ty,z1+tz,'facecolor',fcol,'edgecolor',ecol);
        surf(x2+tx,y2+ty,z2+tz,'facecolor',fcol,'edgecolor',ecol);
        surf(x3+tx,y3+ty,z3+tz,'facecolor',fcol,'edgecolor',ecol);
        surf(x4+tx,y4+ty,z4+tz,'facecolor',fcol,'edgecolor',ecol);
        surf(x5+tx,y5+ty,z5+tz,'facecolor',fcol,'edgecolor',ecol);
        surf(x6+tx,y6+ty,z6+tz,'facecolor',fcol,'edgecolor',ecol);
    case 'roller'                                        # ploting roller sample
        [x,y,z]=cylinder([1 1],30);
        z=(z*hm)-hm/2+tz;  x=x*(wm/2)+tx;  y=y*(wm/2)+ty;
        surf(x,y,z,'facecolor',fcol,'edgecolor',ecol);
        [x,y,z]=sphere(50);
        x=x*(wm/2)+tx;  y=y*(wm/2)+ty;  z1=z*0-hm/2+tz;  z2=z*0+hm/2+tz;
        surf(x,y,z1,'facecolor',fcol,'edgecolor',ecol);
        surf(x,y,z2,'facecolor',fcol,'edgecolor',ecol);
    case 'ball'                                            # ploting ball sample
        [x,y,z]=sphere(30);
        x=(wm/2)*x+tx;  y=(wm/2)*y+ty;  z=(wm/2)*z+tz;
        surf(x,y,z,'facecolor',fcol,'edgecolor',ecol);
    otherwise                              # if sample shape is given incorectly
        disp('Unsupported sample shape!');  return;
    endswitch
endfunction
#*******************************************************************************
function plot_beam(r)
    global src;
    wx=src.width;      hx=src.height;      yx=src.dist;
    ws=src.slwidth;    hs=src.slheight;    ys=src.sldist;
    ecol=[1.0;0.5;0.0];                          # color for beam edges (orange)
    fcol=[1.0;1.0;0.2];                        # color for beam surface (yellow)
                                                      # plot beam direction line
    b0=[0,src.dist,0];  b0=rotxyz(b0,src.rotx,src.roty,src.rotz);
    b1=[0,r,0];         b1=rotxyz(b1,src.rotx,src.roty,src.rotz);
    plot3([b0(1),b1(1)],[b0(2),b1(2)],[b0(3),b1(3)],'color',ecol,'linewidth',2);
    
    switch src.type
    case 'rect'             # plot incident beam for rectangular source and slit
        sx1=[-wx/2;wx/2;wx/2;-wx/2];                            # source corners
        sy1=[yx;yx;yx;yx];
        sz1=[hx/2;hx/2;-hx/2;-hx/2];

        sx2=[-ws/2;ws/2;ws/2;-ws/2];                              # slit corners
        sy2=[ys;ys;ys;ys];
        sz2=[hs/2;hs/2;-hs/2;-hs/2];

        v=[[sx2(1)-sx1(3);sx2(2)-sx1(4);sx2(3)-sx1(1);sx2(4)-sx1(2)],...
           [sy2(1)-sy1(3);sy2(2)-sy1(4);sy2(3)-sy1(1);sy2(4)-sy1(2)],...
           [sz2(1)-sz1(3);sz2(2)-sz1(4);sz2(3)-sz1(1);sz2(4)-sz1(2)]];
        v./=sqrt(sum(v.^2,2))(:,[1 1 1]);                   # normalization to 1
        v=v*(abs(ys)+r);                                    # translation length

        sx3=sx2+v(:,1);                          # beam corners in extended zone
        sy3=sy2+v(:,2);
        sz3=sz2+v(:,3);
        
        c=rotxyz([sx1,sy1,sz1],src.rotx,src.roty,src.rotz);          # rotations
        sx1=c(:,1);   sy1=c(:,2);   sz1=c(:,3);
        c=rotxyz([sx2,sy2,sz2],src.rotx,src.roty,src.rotz);
        sx2=c(:,1);   sy2=c(:,2);   sz2=c(:,3);
        c=rotxyz([sx3,sy3,sz3],src.rotx,src.roty,src.rotz);
        sx3=c(:,1);   sy3=c(:,2);   sz3=c(:,3);
        
        p1x=[sx1(1);sx1(4);sx3(2);sx3(3)];                       # plane 1-4-2-3
        p1y=[sy1(1);sy1(4);sy3(2);sy3(3)];
        p1z=[sz1(1);sz1(4);sz3(2);sz3(3)];

        p2x=[sx1(2);sx1(3);sx3(1);sx3(4)];                       # plane 2-3-1-4
        p2y=[sy1(2);sy1(3);sy3(1);sy3(4)];
        p2z=[sz1(2);sz1(3);sz3(1);sz3(4)];

        p3x=[sx1(1);sx1(2);sx3(4);sx3(3)];                       # plane 1-2-4-3
        p3y=[sy1(1);sy1(2);sy3(4);sy3(3)];
        p3z=[sz1(1);sz1(2);sz3(4);sz3(3)];

        p4x=[sx1(4);sx1(3);sx3(1);sx3(2)];                       # plane 4-3-1-2
        p4y=[sy1(4);sy1(3);sy3(1);sy3(2)];
        p4z=[sz1(4);sz1(3);sz3(1);sz3(2)];

        patch(p1x,p1y,p1z,'y','facecolor',fcol,'edgecolor',ecol);
        patch(p2x,p2y,p2z,'y','facecolor',fcol,'edgecolor',ecol);
        patch(p3x,p3y,p3z,'y','facecolor',fcol,'edgecolor',ecol);
        patch(p4x,p4y,p4z,'y','facecolor',fcol,'edgecolor',ecol);

    case 'circ'                # plot incident beam for circular source and slit
        r0=src.width/2;  r1=-src.slwidth/2;               # source & slit radius
        x0=src.dist;     x1=src.sldist;                 # source & slit position
        x2=r;  a=(r0-r1)/(x0-x1);  b=r1-a*x1;  r2=a*x2+b;
        [x,y,z]=cylinder([r2 r0],50);
        z=z*(abs(src.dist)+r)-r;              # beam cone scalling & translation
        for i=1:size(x,1)                          # beam (source-slit) rotation
        for j=1:size(x,2)
            v=[x(i,j),y(i,j),z(i,j)];
            v=rotxyz(v,90,0,0);          # rotate cone to original beam position
            v=rotxyz(v,src.rotx,src.roty,src.rotz);
            x(i,j)=v(1,1);   y(i,j)=v(1,2);   z(i,j)=v(1,3);
        endfor
        endfor
        surf(x,y,z,'facecolor',fcol,'edgecolor','none');
    
    otherwise                         # if source-slit shape is given incorectly
        disp('Undefined source-slit type!');    return;
    endswitch
endfunction
#*******************************************************************************
function plot_detcone(r)
    global dtctr;
    zd=dtctr.inpos;    lc=dtctr.colength;    xc=dtctr.colx;    yc=dtctr.coly;
    ecol=[0.0;0.6;0.0];                           # color for edges (dark green)
    fcol=[0.2;1.0;0.2];                              # color for surface (green)
                                        # plot direction line to detector center
    d0=[0,0,zd];  d0=rotxyz(d0,dtctr.rotx,dtctr.roty,dtctr.rotz);
    d1=[0,0,-r];  d1=rotxyz(d1,dtctr.rotx,dtctr.roty,dtctr.rotz);
    plot3([d0(1),d1(1)],[d0(2),d1(2)],[d0(3),d1(3)],'color',ecol,'linewidth',2);
    
    if lc>0
    switch dtctr.type
    case 'circ'                    # plot detection cone for circular collimator
        r0=dtctr.colx/2;  r1=-r0;                 # detector & collimator radius
        x0=dtctr.inpos;   x1=x0-dtctr.colength; # detector & collimator position
        x2=-r;  a=(r0-r1)/(x0-x1);  b=r1-a*x1;  r2=a*x2+b;
        [x,y,z]=cylinder([r2 r0],50);
        z=z*(abs(dtctr.inpos)+r)-r;           # beam cone scalling & translation
        for i=1:size(x,1)                          # beam (source-slit) rotation
        for j=1:size(x,2)
            v=[x(i,j),y(i,j),z(i,j)];
            v=rotxyz(v,dtctr.rotx,dtctr.roty,dtctr.rotz);
            x(i,j)=v(1,1);   y(i,j)=v(1,2);   z(i,j)=v(1,3);
        endfor
        endfor
        surf(x,y,z,'facecolor',fcol,'edgecolor','none');    
    
    case 'rect'                # plot detection pyramid for rectangle collimator
        sx1=[xc/2;xc/2;-xc/2;-xc/2];                          # detector corners
        sy1=[-yc/2;yc/2;yc/2;-yc/2];
        sz1=[zd;zd;zd;zd];

        sx2=sx1;                                            # collimator corners
        sy2=sy1;
        sz2=sz1-lc;

        v=[[sx2(1)-sx1(3);sx2(2)-sx1(4);sx2(3)-sx1(1);sx2(4)-sx1(2)],...
           [sy2(1)-sy1(3);sy2(2)-sy1(4);sy2(3)-sy1(1);sy2(4)-sy1(2)],...
           [sz2(1)-sz1(3);sz2(2)-sz1(4);sz2(3)-sz1(1);sz2(4)-sz1(2)]];
        v./=sqrt(sum(v.^2,2))(:,[1 1 1]);                   # normalization to 1
        v=v*(abs(zd)+r);                                    # translation length

        sx3=sx2+v(:,1);             # detection pyramid corners in extended zone
        sy3=sy2+v(:,2);
        sz3=sz2+v(:,3);
        
        c=rotxyz([sx1,sy1,sz1],dtctr.rotx,dtctr.roty,dtctr.rotz);    # rotations
        sx1=c(:,1);   sy1=c(:,2);   sz1=c(:,3);
        c=rotxyz([sx2,sy2,sz2],dtctr.rotx,dtctr.roty,dtctr.rotz);
        sx2=c(:,1);   sy2=c(:,2);   sz2=c(:,3);
        c=rotxyz([sx3,sy3,sz3],dtctr.rotx,dtctr.roty,dtctr.rotz);
        sx3=c(:,1);   sy3=c(:,2);   sz3=c(:,3);
        
        p1x=[sx1(1);sx1(4);sx3(2);sx3(3)];                       # plane 1-4-2-3
        p1y=[sy1(1);sy1(4);sy3(2);sy3(3)];
        p1z=[sz1(1);sz1(4);sz3(2);sz3(3)];

        p2x=[sx1(2);sx1(3);sx3(1);sx3(4)];                       # plane 2-3-1-4
        p2y=[sy1(2);sy1(3);sy3(1);sy3(4)];
        p2z=[sz1(2);sz1(3);sz3(1);sz3(4)];

        p3x=[sx1(1);sx1(2);sx3(4);sx3(3)];                       # plane 1-2-4-3
        p3y=[sy1(1);sy1(2);sy3(4);sy3(3)];
        p3z=[sz1(1);sz1(2);sz3(4);sz3(3)];

        p4x=[sx1(4);sx1(3);sx3(1);sx3(2)];                       # plane 4-3-1-2
        p4y=[sy1(4);sy1(3);sy3(1);sy3(2)];
        p4z=[sz1(4);sz1(3);sz3(1);sz3(2)];

        patch(p1x,p1y,p1z,'y','facecolor',fcol,'edgecolor',ecol);
        patch(p2x,p2y,p2z,'y','facecolor',fcol,'edgecolor',ecol);
        patch(p3x,p3y,p3z,'y','facecolor',fcol,'edgecolor',ecol);
        patch(p4x,p4y,p4z,'y','facecolor',fcol,'edgecolor',ecol);
    
    otherwise                       # if detector type shape is given incorectly
        disp('Undefined detector type!');    return;
    endswitch
    endif
endfunction
#*******************************************************************************
function plot_photons(B,col)
    scatter3(B.r(:,1),B.r(:,2),B.r(:,3),col,'.');
endfunction
#*******************************************************************************