1;	#for octave to recognize this as script file and load all functions
#*******************************************************************************
# Force first collision point inside the sample, weights reduction.
#*******************************************************************************
function [B1]=prop0(B0,outp,fig)                           # Felsteiner's mode
    global smpl;
    disp('_______ PROP no. 0');
    B1=B0;
    dist=sqrt(sum((B1.r-outp).^2,2));
    dist=dist*100;                 # distance between entry and exit points [cm]
    # MAC calculations: mc-coherent, mi-incoherent, mp-photoelectric, mt-total
    mac=maccalc(B1,smpl.name);
    mc=mac(:,2);   mi=mac(:,3);   mp=mac(:,4);   mt=mc+mi+mp;
    miu=mt*smpl.dens;                             # tot. lin. att. coeff. [1/cm]
    # simulation of penetration depth & propagation
    r=rand(size(B1.r,1),1);
    pd=-log(1-r.*(1-exp(-miu.*dist)))./miu/100;          # penetration depth [m]
    B1.r+=B1.k.*pd;                       # propagation to 1st interaction point
    w=1-exp(-miu.*dist);                         # weights from tot. att. coeff.
    B1.wgt=B1.wgt.*w;                                        # weights reduction
    r=rand(size(B1.r,1),1).*(mc+mi);                  # type of 1st interaction:
    B1.pr(r<mc,1)=1;                                   # 1 - coherent scattering
    B1.pr(r>=mc,1)=2;                                # 2 - incoherent scattering
    w=1-(mp./mt);                            # weights: photoabsorption removing
    B1.wgt=B1.wgt.*w;                                        # weights reduction
    B1.loc(:,:)=1;                   # set location mark - inside the sample (1)
    
    if fig=='f'                                                    # test figure
        figure;
        hold on;
        title('PROP0','color','blue','fontsize',16);
        plot_sample('e');
        plot_photons(B1,'b');
        axis("equal");
        view(70,20);
    endif
endfunction
#*******************************************************************************
