1;	#for octave to recognize this as script file and load all functions
#*******************************************************************************
# PROP2DET - scattering forced to detector direction
#    theta - scattering angle
#    omega - angle between electric vectors
#    csn   - current scattering number
#*******************************************************************************
function [B1]=prop2det(csn,B0,fig)
    global ver smpl dtctr;
    disp(['_______ PROP2DET no. ' num2str(csn)]);
#-------------------------------------------------------------------------------
# 1. Change direction (to detector)
    switch ver
    case '1.0'
        [B1,theta]=detdir1(B0);
    case '2.0'
        [B1,theta,omega]=detdir2(B0);
    case '3.0'
        [B1,theta,fi]=detdir3(B0);
    endswitch
#-------------------------------------------------------------------------------
# 2. Energy modification for elastic and inelastic part of the beam
    ela=B1.pr(:,csn)==1;                  # true (T) )for elastic scattering (1)
    inel=B1.pr(:,csn)==2;                # true (T) for inelastic scattering (2)
    switch ver
    case '1.0'
        B1_e=beamextract(B1,ela);
        B1_i=beamextract(B1,inel);
        B1_e=scat_elastic(B1_e,theta(ela,:),[]);      
        B1_i=scat_inelastic(B1_i,theta(inel,:),[]);
    case '2.0'
        B1_e=beamextract(B1,ela);
        B1_i=beamextract(B1,inel);
        B1_e=scat_elastic(B1_e,theta(ela,:),omega(ela,:));
        B1_i=scat_inelastic(B1_i,theta(inel,:),omega(inel,:));
    case '3.0'
        # change Stokes parameters with respect to the scattering plane
        P1=B1.s(:,1);    P2=B1.s(:,2);
        B1.s(:,1)=P1.*cos(2*fi)+P2.*sin(2*fi);
        B1.s(:,2)=-P1.*sin(2*fi)+P2.*cos(2*fi);
        B1_e=beamextract(B1,ela);
        B1_i=beamextract(B1,inel);
        B1_e=scat_elastic(B1_e,theta(ela,:));
        B1_i=scat_inelastic(B1_i,theta(inel,:));
    endswitch
    B1=beammerge(B1_e,B1_i);              # merge elastic and inelastic matrices
#-------------------------------------------------------------------------------
# 3. Propagation (all to exit) & weight reduction
    d=dist2exit(B1);                                  # distance to sample surf.
    B1.r+=B1.k.*d;                                 # propagation to sample surf.
    B1.loc(:,:)=0.5;                              # set location mark to surface
    mac=maccalc(B1,smpl.name);           # mass attenuation coefficients [cm2/g]
    mt=sum(mac(:,2:4),2);           # total mass attenuation coefficient [cm2/g]
    miu=mt*smpl.dens;               # total linear absorption coefficient [1/cm]
    w=exp(-miu.*d*100);                                 # dist is in unit of [m]
    B1.wgt=B1.wgt.*w;                 # weights reduction due to total at. coef.
#-------------------------------------------------------------------------------
# 4. Test figure
    if fig=='f' 
        figure;
        hold on;
        title('PROP2DET','color','blue','fontsize',16);
        plot_sample('e');
        plot_photons(B1,'g');
        axis("equal");
        view(70,20);
    endif
endfunction
#*******************************************************************************
