1;	#for octave to recognize this as script file and load all functions
#*******************************************************************************
# PROP2SAM - random scattering forced to the sample volume
#    theta - scattering angles
#    omega - angles between electric vectors
#       fi - angles between reference and scattering planes
#*******************************************************************************
function [B1]=prop2sam(csn,B0,fig)
    global ver smpl;
    disp(['_______ PROP2SAM no. ' num2str(csn)]);
#-------------------------------------------------------------------------------
# 1. Change direction (random)
    switch ver
    case '1.0'
        [B1,theta]=randir1(B0);
    case '2.0'
        [B1,theta,omega]=randir2(B0);
    case '3.0'
        [B1,theta,fi]=randir3(B0);
    endswitch
#-------------------------------------------------------------------------------
# 2. Energy modification for elastic and inelastic part of the beam
    ela=B1.pr(:,csn)==1;                  # true (T) )for elastic scattering (1)
    inel=B1.pr(:,csn)==2;                # true (T) for inelastic scattering (2)
    switch ver
    case '1.0'
        B1_e=beamextract(B1,ela);
        B1_i=beamextract(B1,inel);
        B1_e=scat_elastic(B1_e,theta(ela,:),[]);
        B1_i=scat_inelastic(B1_i,theta(inel,:),[]);
    case '2.0'
        B1_e=beamextract(B1,ela);
        B1_i=beamextract(B1,inel);
        B1_e=scat_elastic(B1_e,theta(ela,:),omega(ela,:));
        B1_i=scat_inelastic(B1_i,theta(inel,:),omega(inel,:));
    case '3.0'
        # change Stokes parameters with respect to the scattering plane
        P1=B1.s(:,1);  P2=B1.s(:,2);
        B1.s(:,1)=P1.*cos(2*fi)+P2.*sin(2*fi);
        B1.s(:,2)=-P1.*sin(2*fi)+P2.*cos(2*fi);
        B1_e=beamextract(B1,ela);
        B1_i=beamextract(B1,inel);
        B1_e=scat_elastic(B1_e,theta(ela,:),[]);
        B1_i=scat_inelastic(B1_i,theta(inel,:),[]);
    endswitch
    B1=beammerge(B1_e,B1_i);              # merge elastic and inelastic matrices
#-------------------------------------------------------------------------------
# 3. Propagation (all to sample) & weight reduction
    d=dist2exit(B1)*100;                          # distance to exit points [cm]
    mac=maccalc(B1,smpl.name);           # mass attenuation coefficients [cm2/g]
    mt=sum(mac(:,2:4),2);           # total mass attenuation coefficient [cm2/g]
    miu=mt*smpl.dens;                             # tot. lin. att. coeff. [1/cm]
    r=rand(size(B1.r,1),1);                    # simulation of penetration depth
    pd=-log(1-r.*(1-exp(-miu.*d)))./miu/100;             # penetration depth [m]
    B1.r+=B1.k.*pd;                           # propagation to interaction point
    w=1-exp(-miu.*d);                            # weights from tot. att. coeff.
    B1.wgt=B1.wgt.*w;                                        # weights reduction
#-------------------------------------------------------------------------------
# 4. Choose next process (1-elastic scattering, 2-inelastic scattering)
    mc=mac(:,2);  mi=mac(:,3);  mp=mac(:,4);
    r=rand(size(B1.r,1),1).*(mc+mi);                 # type of next interaction:
    B1.pr(r<mc,csn+1)=1;                             # 1 for coherent scattering
    B1.pr(r>=mc,csn+1)=2;                          # 2 for incoherent scattering
    w=1-(mp./mt);            # weights reduction due to photoabsorption removing
    B1.wgt=B1.wgt.*w;
#-------------------------------------------------------------------------------
# 5. Test figure
    if fig=='f'
        figure;
        hold on;
        title('PROP2SAM','color','blue','fontsize',16);
        plot_sample('e');
        plot_photons(B1,'b');
        axis("equal");
        view(70,20);
    endif
endfunction
#*******************************************************************************
