1;	#for octave to recognize this as script file and load all functions
#*******************************************************************************
# Calculates energy scale from momentum scale.
# e0 = incident energies [keV] (table)
# e1 = scattered energies [keV] (table)
# th = scattering angles [rad] (table)
# pz = momentum scale [a.u.] (table)
#*******************************************************************************
# Holm, PRA 37, 3706 (1988):
function [e1]=pz2ec(e0,th,pz)
    m=510.99891;                                   # electron rest mass in [keV]
    alp=1/137.036;                                     # fine structure constant
    pz=pz*m*alp;                                     # momentum in natural units
    Epz=sqrt(m^2+pz.^2);
    A=(e0.^2).*Epz.*(1-cos(th))+e0.*(Epz.^2)-e0.*(pz.^2).*cos(th);
    B=(e0.*(1-cos(th))+Epz).^2-(pz.^2);
    C=sqrt(((A.^2)./(B.^2))-((m^2*e0.^2)./B));
    t1=pz>0;    e1(t1)=(A(t1)./B(t1))+C(t1);
    t0=pz==0;   e1(t0)=(m*e0(t0))./(e0(t0).*(1-cos(th(t0)))+m);
    t2=pz<0;    e1(t2)=(A(t2)./B(t2))-C(t2);
    e1=real(e1)';
endfunction
#*******************************************************************************
# A.Andrejczuk (phd thesis), N.Sakai, J.Phys.Soc.Jpn. 56, 7, 2477-2485 (1987)
function [e1]=pz2ec1(e0,th,pz)
    m=510.99891;                                   # electron rest mass in [keV]
    alp=1/137.036;                                     # fine structure constant
    A=1 ./(1+(e0/m).*(1-cos(th)));
    e1=e0.*A.*(1+sqrt(1+A.^2-2*A.*cos(th)).*pz*alp);
endfunction
#*******************************************************************************
