1;	#for octave to recognize this as script file and load all functions
#*******************************************************************************
# SAVERESULTS - Saving simulation results
#    spectra - energy, momentum, spectra (single, double, triple)
#*******************************************************************************
function saveresults()
    global en sp err nsc resdir src smpl dtctr ver nloops nof nips ev ph ...
           simtime cordir;
    # calculation of momentum scale and effective scattering angle [rad]
    [pz,theff]=momentumscale(en,sp(:,1));
    gth=scancal()*180/pi;                     # geometric scattering angle [deg]
    eth=theff*180/pi;                         # effective scattering angle [deg]
    for i=1:nsc                                       # spectra intensity ratios
        intr(i)=intsplin(en,sp(:,i))/intsplin(en,sum(sp,2));
    endfor
#-------------------------------------------------------------------------------
    disp('************** DATA SAVING:');
    chdir(resdir);                                     # go to results directory
    cordir=datestr(now,'yyyymmdd_HHMMSS');# 1st part of file name as date & time
    mkdir([resdir cordir]);
    fnspec=[resdir cordir '/' cordir '_spc.txt'];      # file for data (spectra)
    fnpars=[resdir cordir '/' cordir '_par.txt'];          # file for parameters
#-------------------------------------------------------------------------------
    # saving energetic spectra of single, double and more scattered photons
    fid=fopen(fnspec,'w');
    fprintf(fid,['  E[keV]  pz[a.u.]      ']);
    for i=1:nsc  fprintf(fid,['S' num2str(i) '            ']);  endfor
    for i=1:nsc  fprintf(fid,['dS' num2str(i) '           ']);  endfor
    fprintf(fid,['\n']);  fprintf(fid,[' -------- --------']);
    for i=1:nsc  fprintf(fid,[' ------------- -------------']);  endfor
    fprintf(fid,['\n']);
    saveformat=' %8.4f %8.4f';
    for i=1:nsc  saveformat=[saveformat ' %e %e'];    endfor
    saveformat=[saveformat '\n'];
    fprintf(fid,saveformat,[en pz sp err]');
    fclose(fid);
    disp(['     Spectra saved in file:  ' fnspec]);
#-------------------------------------------------------------------------------
    # saving simulation parameters
fid=fopen(fnpars,'w');
fprintf(fid,['MUSCAT v' ver ' parameters:\n']);
fprintf(fid,['____________________________________________________________\n']);
fprintf(fid,['SOURCE PARAMETERS:\n\n']);
fprintf(fid,['               Source & slit shape: ' src.type '\n']);
fprintf(fid,['       Photon energy, spread [keV]: ' ...
              num2str(src.energy) ' ' num2str(src.spread) '\n']);
switch src.type
case 'rect'
    fprintf(fid,['Source width, height, position [m]: '...
                  num2str(src.width) ' ' num2str(src.height) ' '...
                  num2str(src.dist) '\n']);
    fprintf(fid,['  Slit width, height, position [m]: '...
                  num2str(src.slwidth) ' ' num2str(src.slheight) ' '...
                  num2str(src.sldist) '\n']);
case 'circ'
    fprintf(fid,['   Source diameter, Y position [m]: '...
                  num2str(src.width) ' ' num2str(src.dist) '\n']);
    fprintf(fid,['     Slit diameter, Y position [m]: '...
                  num2str(src.slwidth) ' ' num2str(src.sldist) '\n']);
endswitch
fprintf(fid,['    Rotations around X, Y, Z [deg]: '...
              num2str(src.rotx) ' ' num2str(src.roty) ' '...
              num2str(src.rotz) '\n']);
fprintf(fid,['                 Stokes parameters: '...
              num2str(src.P1) ' ' num2str(src.P2) ' ' num2str(src.P3) '\n']);
fprintf(fid,['____________________________________________________________\n']);
fprintf(fid,['SAMPLE PARAMETERS:\n\n']);
fprintf(fid,['          Sample material: ' smpl.name '\n']);
fprintf(fid,['            Atomic number: ' num2str(smpl.Z) '\n']);
fprintf(fid,['        Atomic weight [u]: ' num2str(smpl.Ma) '\n']);
fprintf(fid,['         Density [g/cm^3]: ' num2str(smpl.dens) '\n']);
fprintf(fid,['             Sample shape: ' smpl.shape '\n']);
switch smpl.shape
case 'cuboid'
    fprintf(fid,['Width, length, height [m]: ' num2str(smpl.width) ' '...
                  num2str(smpl.length) ' ' num2str(smpl.height) '\n']);
case 'roller'
    fprintf(fid,['     Diameter, height [m]: ' num2str(smpl.width) ' '...
                  num2str(smpl.height) '\n']);
case 'ball'
    fprintf(fid,['             Diameter [m]: ' num2str(smpl.width) '\n']);  
endswitch


fprintf(fid,['Translations: X, Y, Z [m]: ' num2str(smpl.trx) ' '...
              num2str(smpl.try) ' ' num2str(smpl.trz) '\n']);
fprintf(fid,['____________________________________________________________\n']);
fprintf(fid,['DETECTOR PARAMETERS:\n\n']);
fprintf(fid,['              Collimator shape: ' dtctr.type '\n']);
fprintf(fid,['                Z position [m]: ' num2str(dtctr.inpos) '\n']);
switch dtctr.type
case 'rect'
    fprintf(fid,['    Length, x size, y size [m]: '...
                 num2str(dtctr.colength) ' ' num2str(dtctr.colx) ' '...
                 num2str(dtctr.coly) '\n']);
case 'circ'
    fprintf(fid,['          Length, diameter [m]: '...
                 num2str(dtctr.colength) ' ' num2str(dtctr.colx) '\n']);
endswitch
fprintf(fid,['Rotations around X, Y, Z [deg]: ' num2str(dtctr.rotx) ' '...
              num2str(dtctr.roty) ' ' num2str(dtctr.rotz) '\n']);
fprintf(fid,['    Energetic resolution [keV]: ' num2str(dtctr.res) '\n']);
fprintf(fid,['____________________________________________________________\n']);
fprintf(fid,['SIMULATION PARAMETERS:\n\n']);
fprintf(fid,['          Incident photons: ' num2str(nloops*nof) '\n']);
fprintf(fid,['         Photons at sample: ' num2str(nips) '\n']);
fprintf(fid,[' Detected events (photons):\n']);
for i=1:nsc
    fprintf(fid,['               ' num2str(i) ' scattered: '...
                  num2str(ev(i)) ' (' num2str(ph(i)) ')\n']);
endfor
fprintf(fid,['Simulation time [hh:mm:ss]: ' simtime '\n']);
fprintf(fid,['____________________________________________________________\n']);
fprintf(fid,['SIMULATION RESULTS:\n\n']);
fprintf(fid,['          Scat. angle [deg]: ' num2str(gth) '\n']);
fprintf(fid,['     Eff. scat. angle [deg]: ' num2str(eth) '\n']);
fprintf(fid,['\n   Spectra intensity ratios:\n']);
for i=1:nsc
    fprintf(fid,['                    ' num2str(i) '/total: '...
                  num2str(intr(i)) '\n']);
endfor
fprintf(fid,['____________________________________________________________\n']);
fclose(fid);
disp(['  Parameters saved in file:  ' fnpars]);
endfunction
#*******************************************************************************
function saveresults2()
    global resdir cordir sp2 err2;
    disp(['************** DATA SAVING 2:']);
    chdir(resdir);                                     # go to results directory
#   cordir=datestr(now,'yyyymmdd_HHMMSS');# 1st part of file name as date & time
    mkdir([resdir cordir]);
    fnspec=[resdir cordir '/' cordir '_spc2.txt']; # file for data (spectra)
    fid=fopen(fnspec,'w');
    fprintf(fid,['      e-e           e-i           i-e           i-i     ']);
    fprintf(fid,['      dee           dei           die           dee\n']);
    fprintf(fid,[' ------------- ------------- ------------- ------------- ']);
    fprintf(fid,['------------- ------------- ------------- -------------\n']);
    saveformat=' %e %e %e %e %e %e %e %e\n'; 
    fprintf(fid,saveformat,[sp2 err2]');
    fclose(fid);
    disp(['     Spectra saved in file:  ' fnspec]);
endfunction
#*******************************************************************************
