1;	#for octave to recognize this as script file and load all functions
#*******************************************************************************
# Elastic scattering - weight reduction due to elastic cross section.
#*******************************************************************************
function [B1]=scat_elastic(B0,theta,omega)
    global smpl ver;
    B1=B0;
    re=2.8179403267e-13;                        # classical electron radius [cm]
    u=1.660538921e-24;                                    # atomic mass unit [g]
    mac=maccalc(B0,smpl.name);           # mass attenuation coefficients [cm2/g]
    sig=mac(:,2)*u*smpl.Ma;             # total CS for coherent scattering [cm2]
    F=affcalc(B0,smpl.name,theta);              # atomic form factor calculation
    F=anomalous(F,B0.ene,smpl.name);   # AFF correction for anomalous scattering
    switch ver
    case '1.0'
        w=(2*pi*re^2 ./sig).*(1+cos(theta).^2).*(F.^2);
    case '2.0'
        w=(4*pi*re^2 ./sig).*cos(omega).^2 .*(F.^2);
    case '3.0'
        P1=B0.s(:,1);    P2=B0.s(:,2);
        GR=1+((P1-1)./2).*sin(theta).^2;
        w=(4*pi*re^2 ./sig).*GR.*(F.^2);
        # new Stokes parameters referred to scattering plane:
        B1.s(:,1)=((1+P1)-(1-P1).*cos(theta).^2)./(2-(1-P1).*sin(theta).^2);
        B1.s(:,2)=(2*cos(theta).*P2)./(2-(1-P1).*sin(theta).^2);
    endswitch
    B1.wgt=B1.wgt.*w;                                         # weight reduction
#    ecs0=w.*sig./(4*pi)./(F.^2);                   # cross section test figures
#    ecs1=w.*sig./(4*pi);
#    figure; plot(theta,ecs0,'.');
#    figure; plot(theta,ecs1,'.');
endfunction
#*******************************************************************************
