1;	#for octave to recognize this as script file and load all functions
#*******************************************************************************
# Inelastic scattering, change of photon energy, weight reduction due to
# inelastic cross section.
#*******************************************************************************
function [B1]=scat_inelastic(B0,theta,omega)
    global ver smpl;
    B1=B0;
    re=2.8179403267e-13;                        # classical electron radius [cm]
    u=1.660538921e-24;                                    # atomic mass unit [g]
    m0c2=510.998928;                                # electron rest energy [keV]
    alp=1/137.036;                                     # fine structure constant
    e0=B0.ene;                                    # incident photon energy [keV]
    [p,j]=comptload(smpl.name);                     # load Compton profile shape
    pz=mrand(size(B1.r,1),p,j);             # choose electron momentum pz [a.u.]
    e1=pz2ec(e0,theta,pz);                       # scattered photon energy [keV]
    B1.ene=e1;
#    if or(find(e1<0))
#        disp('SCAT_INELASTIC: scattered photon energy < 0 found');
#        disp('Please reduce the momentum range in COMPTLOAD.SCI');  break;
#    end
    de=e0-e1;                                                  # energy transfer
    B1.wgt(de<=0,:)=0;           # weight reduction for negative energy transfer
    eC=e0./(1+(e0/m0c2).*(1-cos(theta)));                 # Compton center [keV]
    bw=binding(e0,e1,pz,smpl.name);       # weight correction for binding energy
    B1.wgt=B1.wgt.*bw;
    mac=maccalc(B0,smpl.name);                        # MAC calculations [cm2/g]
    sig=mac(:,3)*u*smpl.Ma;                 # CS for incoherent scattering [cm2]
    S=isfcalc(B0,smpl.name,theta);                             # ISF calculation
    switch ver
    case '1.0'
        eC0=eC./e0;    e0C=e0./eC;
        w=(2*pi*re^2 ./sig).*(eC0.^2 .*(e0C+eC0-sin(theta).^2)).*S;
    case '2.0'
        eC0=eC./e0;    e0C=e0./eC;
        w=(pi*re^2 ./sig).*(eC0.^2 .*(e0C+eC0-2+4.*cos(omega).^2)).*S;
    case '3.0'
        P1=B1.s(:,1);    P2=B1.s(:,2);
        GC=((e0./eC)+(eC./e0)+(P1-1).*sin(theta).^2)/2;
        w=(4*pi*re^2 ./sig).*((eC./e0).^2 .*GC).*S;
        # new Stokes parameters referred to scattering plane:
        FC=(e1./e0)+(e0./e1);       
        B1.s(:,1)=((1+P1)-(1-P1).*cos(theta).^2)./(FC-(1-P1).*sin(theta).^2);
        B1.s(:,2)=(2*cos(theta).*P2)./(FC-(1-P1).*sin(theta).^2);
    endswitch
    B1.wgt=B1.wgt.*w;                                         # weight reduction
    #ics0=w.*sig./(4*pi)./S;                        # cross section test figures
    #ics1=w.*sig./(4*pi);
    #figure; plot(theta,ics0,'.');
    #figure; plot(theta,ics1,'.');
endfunction
#*******************************************************************************
